@@ -3,8 +3,12 @@ import logging
 import os
 import sys
 
+PROJECT_DIR = os.path.abspath(__file__)
+sys.path.append(PROJECT_DIR)
+
 if __name__ == "__main__":
 
+
     os.environ.setdefault("DJANGO_SETTINGS_MODULE", "crm.settings")
 
     try:
